<!-- !split -->
<!-- jupyter-book 02_19_testdoc.md -->
# Bibliography test

Here is an example: <a href="07_testdoc.html#Langtangen_Pedersen_2002">[1]</a> discussed propagation of
large destructive water waves, <a href="07_testdoc.html#Langtangen_et_al_2002">[2]</a> gave
an overview of numerical methods for solving the Navier&ndash;Stokes equations,
while the use of Backward Kolmogorov equations for analyzing
random vibrations was investigated in <a href="07_testdoc.html#Langtangen_1994a">[3]</a>.
The book chapter <a href="07_testdoc.html#Mardal_et_al_2003a">[4]</a> contains information on
C++ software tools for programming multigrid methods. A real retro
reference is <a href="07_testdoc.html#Langtangen_1988d">[5]</a> about a big FORTRAN package.
Multiple references are also possible, e.g., see
<a href="07_testdoc.html#Langtangen_Pedersen_2002">[1]</a> <a href="07_testdoc.html#Mardal_et_al_2003a">[4]</a>.

We need to cite more than 10 papers to reproduce an old formatting
problem with blanks in the keys in reST format:
<a href="07_testdoc.html#Langtangen_1992c">[6]</a> <a href="07_testdoc.html#Langtangen_1994a">[3]</a> <a href="07_testdoc.html#Mortensen_et_al_2011">[7]</a> <a href="07_testdoc.html#Langtangen_Pedersen_2002">[1]</a>
and
<a href="07_testdoc.html#Langtangen_et_al_2002">[2]</a> <a href="07_testdoc.html#Glimsdal_et_al_20006">[8]</a> <a href="07_testdoc.html#Rahman_et_al_2006b">[9]</a> <a href="07_testdoc.html#Haga_et_al_2011a">[10]</a> <a href="07_testdoc.html#Langtangen_2003a">[11]</a> <a href="07_testdoc.html#Langtangen_2008a">[12]</a> <a href="07_testdoc.html#Langtangen:95">[13]</a>
and all the work of
<a href="07_testdoc.html#Langtangen_2012">[14]</a> <a href="07_testdoc.html#Mardal_et_al_2003a">[4]</a> <a href="07_testdoc.html#Jeberg_et_al_2004">[15]</a> as well as
old work <a href="07_testdoc.html#Langtangen_1988d">[5]</a> and <a href="07_testdoc.html#Langtangen_1989e">[16]</a>, and the
talk <a href="07_testdoc.html#Langtangen_talk_2007a">[17]</a>.
Langtangen also had two thesis <a href="07_testdoc.html#Langtangen:85">[18]</a> <a href="07_testdoc.html#Langtangen_1989e">[16]</a>
back in the days.
More retro citations are
the old ME-IN323 book <a href="07_testdoc.html#Langtangen:91">[19]</a> and the
<a href="07_testdoc.html#Langtangen:94b">[20]</a> OONSKI '94 paper.

